:orphan:

Pint: makes units easy
======================

**Useful links**:
`Code Repository <https://github.com/hgrecco/pint-pandas>`__ |
`Issues <https://github.com/hgrecco/pint-pandas/issues>`__ |



.. grid:: 1 1 2 2
    :gutter: 2

    .. grid-item-card::
        :img-top: _static/index_getting_started.svg
        :link: getting/index
        :link-type: doc

        Getting Started
        ^^^^^^^^^^^^^^^

        New to pint-pandas? Check out the getting started guides. They contain an
        introduction to pint-pandas's main concepts and links to additional tutorials.

    .. grid-item-card::
        :img-top: _static/index_user_guide.svg
        :link: user/index
        :link-type: doc

        User Guide
        ^^^^^^^^^^

        The user guide provides in-depth information on the
        key concepts of pint-pandas with useful background information and explanation.

    .. grid-item-card::
        :img-top: _static/index_api.svg
        :link: api/base
        :link-type: doc

        API reference
        ^^^^^^^^^^^^^

        The reference guide contains a detailed description of the pint-pandas API.
        The reference describes how the methods work and which parameters can
        be used. It assumes that you have an understanding of the key concepts.

    .. grid-item-card::
        :img-top: _static/index_contribute.svg
        :link: dev/contributing
        :link-type: doc

        Developer guide
        ^^^^^^^^^^^^^^^

        Saw a typo in the documentation? Want to improve existing functionalities?
        The contributing guidelines will guide you through the process of improving
        pint-pandas.


.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: For users

    Getting started <getting/index>
    User Guide <user/index>
    Advanced topics <advanced/index>
    ecosystem
    API Reference <api/index>

.. toctree::
    :maxdepth: 1
    :hidden:
    :caption: For developers

    dev/contributing
    dev/pint-convert

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Community

    GitHub repository <https://github.com/hgrecco/pint-pandas>
